Point2

Struct Point2 

pub struct Point2 { /* private fields */ }
A 2D point represented with f64 coordinates.

Implementations

Source

impl Point2

pub const fn new(x: f64, y: f64) -> Self

Creates a point from x and y coordinates.

pub const fn x(&self) -> f64

Returns the horizontal coordinate.

pub const fn y(&self) -> f64

Returns the vertical coordinate.

pub const fn try_new(x: f64, y: f64) -> Result<Self, GeometryError>

Creates a point from finite x and y coordinates.

Errors

Returns GeometryError::NonFiniteComponent when x or y is NaN or infinite.

pub const fn validate(self) -> Result<Self, GeometryError>

Validates that an existing point contains only finite coordinates.

Errors

Returns GeometryError::NonFiniteComponent when self.x or self.y is NaN or infinite.

pub const fn is_finite(self) -> bool

Returns true when both coordinates are finite.

pub const fn origin() -> Self

Returns the origin (0, 0).

pub fn distance_to(self, other: Self) -> f64

Returns the Euclidean distance to another point.

pub fn distance_squared_to(self, other: Self) -> f64

Returns the squared Euclidean distance to another point.

pub const fn midpoint(self, other: Self) -> Self

Returns the midpoint between this point and another point.

pub const fn lerp(self, other: Self, t: f64) -> Self

Returns a point interpolated between this point and other.

pub const fn translate(self, vector: Vector2) -> Self

Returns a point translated by a vector.